pub fn eval(a: &[IndexedFunc], b: &[IndexedFunc]) -> EvalResultExpand description
rank every signal-bearing function in A against all of B, using symbol names as ground truth. this is the headline accuracy measurement.
pub fn eval(a: &[IndexedFunc], b: &[IndexedFunc]) -> EvalResultrank every signal-bearing function in A against all of B, using symbol names as ground truth. this is the headline accuracy measurement.